@@ -5,15 +5,16 @@ import operator as op
 NUMBER_RE = re('(\d*\.?\d*)')
 CONVERT = {
     "bytes": (
-        ("GB", 1000000000.0),
-        ("MB", 1000000.0),
-        ("KB", 1000.0),
+        ("TB", 1099511627776), ("GB", 1073741824.0), ("MB", 1048576.0), ("KB", 1024.0),
+    ),
+    "bits": (
+        ("Tb", 1099511627776), ("Gb", 1073741824.0), ("Mb", 1048576.0), ("Kb", 1024.0),
+    ),
+    "bps": (
+        ("Gbps", 1000000000.0), ("Mbps", 1000000.0), ("Kbps", 1000.0),
     ),
     "short": (
-        ("Tri", 1000000000000.0),
-        ("Bil", 1000000000.0),
-        ("Mil", 1000000.0),
-        ("K",   1000.0),
+        ("Tri", 1000000000000.0), ("Bil", 1000000000.0), ("Mil", 1000000.0), ("K",   1000.0),
     ),
     "s": (
         ("y", 31536000.0),
@@ -102,4 +103,4 @@ def parse_rule(rule):
     if cond not in OPERATORS:
         raise ValueError('Invalid operator: %s for rule %s' % (cond, rule))
     op = OPERATORS[cond]
-    return {'level': level, 'op': op, 'value': value, 'mod': mod or DEFAULT_MOD}
+    return {'level': level, 'op': op, 'value': value, 'mod': mod or DEFAULT_MOD, 'raw': rule}
